from random import randint, seed
from math import sqrt
seed(47)

LIMITS = [ 1, 10, 10**2, 10**3, 10**4, 10**6, 10**7, 10**9, 5*10**10, 3*10**11, 10**12 ]
SAMPLES = [ 12, 27, 11 ]

def save(fname, n):
    f = open(fname, 'w')
    print(n, file=f)
    f.close()

def is_prime(n):
    s = int(sqrt(n)+.1)
    return n >= 2 and not any( n%d == 0 for d in range(2,s+1) )

def gen_prime(lo,hi):
    while True:
        p = randint(lo,hi)
        if is_prime(p): return p

def gen_prime_square(lo,hi):
    llo = int(sqrt(lo))+1
    hhi = int(sqrt(hi))
    while True:
        p = randint(llo,hhi)
        if is_prime(p): return p*p

def gen_two_primes(lo,hi):
    llo = int(sqrt(lo))+1
    hhi = int(sqrt(hi))
    P = set()
    while True:
        p = randint(llo,hhi)
        if is_prime(p):
            P.add(p)
            if len(P) == 2:
                p, q = list(P)
                return p*q

def gen_two_primes_v2(lo,hi):
    llo = int(sqrt(lo))+1
    hhi = int(sqrt(hi))
    while True:
        P = set()
        while True:
            p = randint(llo,hhi)
            if is_prime(p):
                P.add(p)
                if len(P) == 2:
                    break
        p, q = list(sorted(P))
        n = p*(q+1)
        if lo <= n <= hi: return n

save('00.sample.1.in', SAMPLES[0])
save('00.sample.2.in', SAMPLES[1])
save('00.sample.3.in', SAMPLES[2])

for subtask in range(1,11):
    tests = set()
    tests.add( LIMITS[subtask] )
    tests.add( gen_prime( LIMITS[subtask-1]+1, LIMITS[subtask] ) )
    tests.add( gen_prime_square( LIMITS[subtask-1]+1, LIMITS[subtask] ) )
    tests.add( gen_two_primes( LIMITS[subtask-1]+1, LIMITS[subtask] ) )
    tests.add( gen_two_primes_v2( LIMITS[subtask-1]+1, LIMITS[subtask] ) )
    while len(tests) < 9:
        add = randint( LIMITS[subtask-1]+1, LIMITS[subtask] )
        if add not in tests: tests.add(add)
    for tid, n in enumerate(reversed(sorted(tests))):
        save('{:02d}.{}.in'.format(subtask,tid+1), n)

